@@ -13,7 +13,7 @@ import torch
 
 
 class TorusConv2d(torch.nn.Module):
-    """ """
+    """description"""
 
     def __init__(self, input_dim: int, output_dim: int, kernel_size, bn: bool):
         super().__init__()
