@@ -6,3 +6,6 @@ __doc__ = r"""
 
            Created on 15/07/2020
            """
+
+from .ram import *
+from .ram_modules import *
