@@ -1,6 +1,15 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "Christian Heider Nielsen"
+__doc__ = r"""
+           """
+
 from torch import nn
 from torch.nn.utils import spectral_norm
 
+__all__ = ["spectral_norm_conv2d", "spectral_norm_linear", "spectral_norm_embedding"]
+
 
 def spectral_norm_conv2d(
     in_channels,
