@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 __author__ = "Christian Heider Nielsen"
-__doc__ = ""
+__doc__ = """
+"""
 
 # from .datasets import *
 # from .neodroid_environments import *
