@@ -21,9 +21,9 @@ import pycocotools.mask
 import torch
 import torch._six
 import torchvision
-from draugr.python_utilities.exceptions import IncompatiblePackageVersions
 from pycocotools.coco import COCO  # Version 2.0 REQUIRES numpy 1.17
 from pycocotools.cocoeval import COCOeval
+from warg import IncompatiblePackageVersions
 
 if pycocotools.coco.__version__ == "2.0" and "1.18" in numpy.__version__:
     print("Hint: downgrade numpy to 1.17.x")
@@ -58,7 +58,7 @@ class IouType(Enum):
 
 
 class CocoEvaluator(object):
-    """ """
+    """description"""
 
     def __init__(self, coco_api: COCO, iou_types: Sequence[IouType]):
         assert isinstance(iou_types, (list, tuple))
@@ -93,7 +93,7 @@ class CocoEvaluator(object):
             self.eval_imgs[iou_type].append(eval_imgs)
 
     def synchronize_between_processes(self):
-        """ """
+        """description"""
         for iou_type in self.iou_types:
             self.eval_imgs[iou_type] = numpy.concatenate(self.eval_imgs[iou_type], 2)
             create_common_coco_eval(
@@ -101,12 +101,12 @@ class CocoEvaluator(object):
             )
 
     def accumulate(self):
-        """ """
+        """description"""
         for coco_eval in self.coco_eval.values():
             coco_eval.accumulate()
 
     def summarize(self):
-        """ """
+        """description"""
         for iou_type, coco_eval in self.coco_eval.items():
             print(f"IoU metric: {iou_type}")
             coco_eval.summarize()
@@ -382,7 +382,10 @@ def create_index(self):
 def load_results(self, resFile) -> COCO:
     """
     Load result file and return a result api object.
-    :param   resFile (str)     : file name of result file
+    :param self:
+    :type self:
+    :param resFile:
+    :type resFile:
     :return: res (obj)         : result api object"""
     res = COCO()
     res.dataset["images"] = [img for img in self.dataset["images"]]
