@@ -1,10 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "{user}"
+__author__ = "Christian Heider Nielsen"
 __doc__ = r"""
-
-           Created on {date}
            """
 
 from typing import Tuple
@@ -15,16 +13,20 @@ from neodroidvision.data.detection.object_detection_dataset import (
 
 
 class MnistDetectionDataset(ObjectDetectionDataset):
+    """description"""
+
     def __init__(self, download: bool = True):
         super().__init__()
         # TODO: FINISH
 
     @property
     def response_shape(self) -> Tuple[int, ...]:
+        """description"""
         pass
 
     @property
     def predictor_shape(self) -> Tuple[int, ...]:
+        """description"""
         pass
 
     def __len__(self):
