@@ -8,7 +8,7 @@ from pathlib import Path
 
 import numpy
 from PIL import Image, ImageEnhance
-from tqdm import tqdm
+from draugr.visualisation import progress_bar
 
 from neodroidvision.data.synthesis.conversion.mnist.json_generation.mask_json_utilities import (
     MaskJsonUtils,
@@ -191,7 +191,7 @@ class ImageComposition:
         mju = MaskJsonUtils(self.output_dir)
 
         # Create all images/masks (with tqdm to have a progress bar)
-        for i in tqdm(range(self.count)):
+        for i in progress_bar(range(self.count)):
             # Randomly choose a background
             background_path = random.choice(self.backgrounds)
 
@@ -460,7 +460,7 @@ if __name__ == "__main__":
         required=True,
         help="The directory where "
         "images, masks, \
-                                                        and json files will be placed",
+                                                                             and json files will be placed",
     )
     parser.add_argument(
         "--count",
