@@ -1,14 +1,22 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "Christian Heider Nielsen"
+__doc__ = r"""
+
+           Created on 10/11/2019
+           """
+
 import torch
 from torch import nn
 
 __all__ = ["SingleShotDetection"]
-__doc__ = r""""""
 
 from warg import NOD
 
 
 class SingleShotDetection(nn.Module):
-    """ """
+    """description"""
 
     def __init__(self, cfg: NOD):
         super().__init__()
