@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "Christian Heider Nielsen"
+__doc__ = r"""
+
+           Created on 10/11/2019
+           """
+
 from typing import List
 
 import torch
@@ -16,7 +25,7 @@ from warg import NOD
 
 
 class SingleShotDetectionNms(SingleShotDetection):
-    """ """
+    """description"""
 
     def __init__(self, cfg: NOD):
         super().__init__(cfg)
@@ -41,5 +50,5 @@ class SingleShotDetectionNms(SingleShotDetection):
         return self.box_head(super().forward(images))
 
     def post_init(self) -> None:
-        """ """
+        """description"""
         self.box_head.post_init(**self.priors_cfg)
