@@ -7,15 +7,15 @@ __doc__ = r"""
            Created on 09/02/2020
            """
 
-import draugr
 import fire
+import warg
 from pyfiglet import Figlet
 
 from neodroidvision import get_version
 
 sponsors = "Alexandra Institute"
 margin_percentage = 0 / 6
-terminal_width = draugr.get_terminal_size().columns
+terminal_width = warg.get_terminal_size().columns
 margin = int(margin_percentage * terminal_width)
 width = terminal_width - 2 * margin
 underline = "_" * width
@@ -24,7 +24,7 @@ indent = " " * margin
 
 class NeodroidVisionCLI(object):
     def run(self) -> None:
-        """ """
+        """description"""
         pass
 
     @staticmethod
@@ -36,7 +36,7 @@ class NeodroidVisionCLI(object):
 
     @staticmethod
     def sponsors() -> None:
-        """ """
+        """description"""
         print(sponsors)
 
 
