@@ -19,7 +19,7 @@ from sorcery import assigned_names
 
 
 class SelfAttentionTypeEnum(Enum):
-    """ """
+    """description"""
 
     (
         pairwise,  # pairwise subtraction 0
@@ -28,7 +28,7 @@ class SelfAttentionTypeEnum(Enum):
 
 
 class PadModeEnum(Enum):
-    """ """
+    """description"""
 
     zero_pad, ref_pad = assigned_names()
 
