@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 26/01/2022
+           """
+
 from collections import namedtuple
 from string import Template
 from typing import Any
