@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 26/01/2022
+           """
+
 import torch
 from torch import nn
 from torch.nn.modules.utils import _pair
@@ -11,7 +20,7 @@ __all__ = ["Subtraction"]
 
 
 class Subtraction(nn.Module):
-    """ """
+    """description"""
 
     def __init__(
         self,
