@@ -9,23 +9,28 @@ __doc__ = r"""
 
 import torch
 
+__all__ = ["cache_backbone_results", "switch_target_head", "common_head_training"]
 
-def cache_backbone_results(model: torch.Module) -> None:
+
+def cache_backbone_results(model: torch.nn.Module) -> None:
     """
     Cache and freeze the backbone part of the model and only update heads
     """
     pass
+    raise NotImplementedError
 
 
-def switch_target_head(model: torch.Module) -> None:
+def switch_target_head(model: torch.nn.Module) -> None:
     """
     Only single head at a time
     """
     pass
+    raise NotImplementedError
 
 
-def common_head_training(model: torch.Module) -> None:
+def common_head_training(model: torch.nn.Module) -> None:
     """
     Train all heads a the same time
     """
     pass
+    raise NotImplementedError
