@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 __author__ = "Christian Heider Nielsen"
-__doc__ = ""
+__doc__ = """ description """
 
 from .flow import *
 from .generative import *
