@@ -20,7 +20,8 @@ def dice_coefficient(img1, img2, threshold=0.5) -> float:
       img2:
 
     Returns:
-
+    :param threshold:
+    :type threshold:
     """
     img1 = numpy.asarray(img1) > threshold
     img2 = numpy.asarray(img2) > threshold
@@ -30,6 +31,17 @@ def dice_coefficient(img1, img2, threshold=0.5) -> float:
 
 
 def intersection_over_union(img1, img2, threshold=0.5) -> float:
+    """
+
+    :param img1:
+    :type img1:
+    :param img2:
+    :type img2:
+    :param threshold:
+    :type threshold:
+    :return:
+    :rtype:
+    """
     img1 = numpy.asarray(img1) > threshold
     img2 = numpy.asarray(img2) > threshold
 
