@@ -1,4 +1,13 @@
-from typing import Tuple, Mapping, Any
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 5/5/22
+           """
+
+from typing import Any, Mapping, Tuple
 
 import cv2
 import numpy
@@ -12,7 +21,7 @@ __all__ = [
 ]
 
 
-def eccentricity_from_moments(moments: Mapping):
+def eccentricity_from_moments(moments: Mapping) -> Tuple[Number, Number]:
     """The eccentricity is calculated by contour moment"""
     a1 = (moments["mu20"] + moments["mu02"]) / 2
     a2 = (
@@ -29,7 +38,7 @@ def gravity_center_from_moments(moments: Mapping) -> Tuple[Number, Number]:
     :return:
     :rtype:
     """
-    return (int(moments["m10"] / moments["m00"]), int(moments["m01"] / moments["m00"]))
+    return int(moments["m10"] / moments["m00"]), int(moments["m01"] / moments["m00"])
 
 
 def gravity_center(c: Any) -> Tuple[Number, Number]:
