@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 5/5/22
+           """
+
 import cv2
 import numpy
 from draugr.opencv_utilities import show_image, to_gray
@@ -6,6 +15,13 @@ __all__ = ["skeletonise", "top_skeleton", "thin"]
 
 
 def top_skeleton(img):
+    """
+
+    :param img:
+    :type img:
+    :return:
+    :rtype:
+    """
     size = numpy.size(img)
 
     element = cv2.getStructuringElement(cv2.MORPH_CROSS, (3, 3))
@@ -24,6 +40,13 @@ def top_skeleton(img):
 
 
 def skeletonise(image):
+    """
+
+    :param image:
+    :type image:
+    :return:
+    :rtype:
+    """
     return cv2.ximgproc.thinning(image)
 
 
@@ -32,6 +55,7 @@ thin = skeletonise
 if __name__ == "__main__":
 
     def uahsd():
+        """description"""
         # file = "360_F_108702068_Z9VGab1DfiyPzq2v5Xgm2wRljttzRGgq.jpg"
         file = "NdNLO.jpg"
 
@@ -45,6 +69,7 @@ if __name__ == "__main__":
         cv2.destroyAllWindows()
 
     def uahsd2():
+        """description"""
         # file = "360_F_108702068_Z9VGab1DfiyPzq2v5Xgm2wRljttzRGgq.jpg"
         file = "NdNLO.jpg"
 
@@ -57,4 +82,4 @@ if __name__ == "__main__":
         show_image(skel, wait=True)
         cv2.destroyAllWindows()
 
-    uahsd2()
+        uahsd2()
