@@ -13,12 +13,28 @@ import cv2
 
 
 def variance_of_laplacian(image):
+    """
+
+    :param image:
+    :type image:
+    :return:
+    :rtype:
+    """
     # compute the Laplacian of the image and then return the focus
     # measure, which is simply the variance of the Laplacian
     return cv2.Laplacian(image, cv2.CV_64F).var()
 
 
 def is_picture_blurry(image, threshold=100) -> bool:
+    """
+
+    :param image:
+    :type image:
+    :param threshold:
+    :type threshold:
+    :return:
+    :rtype:
+    """
     return variance_of_laplacian(image) < threshold
 
 
