@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 5/5/22
+           """
+
 from typing import Iterable, Tuple
 
 from draugr.torch_utilities import NamedTensorTuple
@@ -7,7 +16,7 @@ __all__ = ["BatchCollator"]
 
 
 class BatchCollator:
-    """ """
+    """description"""
 
     def __init__(self, wrap: bool = True):
         self.wrap = wrap
