@@ -1,3 +1,12 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 5/5/22
+           """
+
 import pickle
 from typing import Any, List
 
@@ -28,10 +37,11 @@ def serialise_byte_tensor(
     """
 
 
+    :param device:
+    :type device:
     :param encoded_data:
     :param data:
-    :return:
-    """
+    :return:"""
 
     tensor = to_byte_tensor(data, device=device)
 
