@@ -1,10 +1,19 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+__author__ = "heider"
+__doc__ = r"""
+
+           Created on 5/5/22
+           """
+
 from torch import nn
 
 __all__ = ["SeparableConv2d"]
 
 
 class SeparableConv2d(nn.Module):
-    """"""
+    """description"""
 
     def __init__(
         self,
