@@ -1,14 +1,20 @@
 import torch
 from torchvision.transforms.functional import to_pil_image
-
-from utilities.torch_utilities.patches.shuffle import extract_patches, combine_patches
+from utilities.torch_utilities.patches.shuffle import combine_patches, extract_patches
 from utilities.torch_utilities.transforms.image_transforms import BaseTorchTransform
 
 __all__ = ["BlockyShuffle"]
 
 
 def shuffle_patches(patches: torch.Tensor):
-    patches
+    """
+
+    :param patches:
+    :type patches:
+    :return:
+    :rtype:
+    """
+    return patches  # TODO
 
 
 class BlockyShuffle(BaseTorchTransform):
@@ -23,6 +29,13 @@ class BlockyShuffle(BaseTorchTransform):
         self.patch_size = patch_size
 
     def forward(self, img):
+        """
+
+        :param img:
+        :type img:
+        :return:
+        :rtype:
+        """
         img, retmode = super().forward(img)
 
         img = img.unsqueeze(0)
