@@ -1,10 +1,11 @@
 import torch
-
 from torch import nn
-from torch.nn.functional import unfold, fold
+from torch.nn.functional import fold, unfold
 
 
 class ShufflePatches(nn.Module):
+    """description"""
+
     def __init__(self, patch_size):
         super().__init__()
         self.patch_size = patch_size
@@ -29,6 +30,7 @@ class ShufflePatches(nn.Module):
 if __name__ == "__main__":
 
     def asidj():
+        """description"""
         from cv2 import circle
         import numpy
 
@@ -46,4 +48,4 @@ if __name__ == "__main__":
         pyplot.imshow(shuffled.squeeze(0).permute(1, 2, 0).to(dtype=torch.int))
         pyplot.show()
 
-    asidj()
+        asidj()
