@@ -1,3 +1,7 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
+
 from itertools import cycle
 from typing import Iterable, Optional, Sequence, Tuple, Union
 
@@ -354,15 +358,16 @@ def draw_bounding_box_on_image(
         for display_str in labels[::-1]:
             text_width, text_height = font.getsize(display_str)
             margin = numpy.ceil(0.05 * text_height)
+
             draw.rectangle(
                 [
                     (text_left, text_bottom - text_height - 2 * margin),
-                    (text_left + text_width, text_bottom),
+                    (text_left + text_width + margin, text_bottom),
                 ],
                 fill=line_color.value,
             )
             draw.text(
-                (text_left + margin, text_bottom - text_height - margin),
+                (text_left + margin, text_bottom - text_height - 2 * margin),
                 display_str,
                 fill=text_color.value,
                 font=font,
@@ -542,6 +547,7 @@ def draw_keypoints_on_image(
     color: ColorEnum = None,
     radius: Number = 2,
     use_normalized_coordinates: bool = True,
+    # TODO: ADD LABELS
 ):
     """Draws keypoints on an image.
 
@@ -663,6 +669,16 @@ def visualize_boxes_and_labels_on_image_array(
 
     Returns:
     uint8 numpy array with shape (img_height, img_width, 3) with overlaid boxes.
+    :param image:
+    :type image:
+    :param use_normalized_coordinates:
+    :type use_normalized_coordinates:
+    :param max_boxes_to_draw:
+    :type max_boxes_to_draw:
+    :param min_score_thresh:
+    :type min_score_thresh:
+    :param line_thickness:
+    :type line_thickness:
     :param bounding_boxes:"""
     # Create a display string (and color) for every box location, group any boxes
     # that correspond to the same location.
@@ -743,7 +759,7 @@ def cdf_plot(values):
 if __name__ == "__main__":
 
     def main():
-        """ """
+        """description"""
         im = numpy.random.rand(256, 256, 4)
         bb = numpy.array(
             [
@@ -765,7 +781,7 @@ if __name__ == "__main__":
         pyplot.show()
 
     def main2():
-        """ """
+        """description"""
         im = numpy.random.rand(256, 256, 3)
         bb = numpy.array(
             [
@@ -787,7 +803,7 @@ if __name__ == "__main__":
         pyplot.show()
 
     def main3():
-        """ """
+        """description"""
         im = numpy.random.rand(256, 256)
         bb = numpy.array(
             [
